@@ -1,9 +1,8 @@
-from __future__ import unicode_literals
-
 import os
+from typing import Callable, Iterable, Union
 
-from .metrics_core import CounterMetricFamily, GaugeMetricFamily
-from .registry import REGISTRY
+from .metrics_core import CounterMetricFamily, GaugeMetricFamily, Metric
+from .registry import Collector, CollectorRegistry, REGISTRY
 
 try:
     import resource
@@ -14,10 +13,14 @@ except ImportError:
     _PAGESIZE = 4096
 
 
-class ProcessCollector(object):
+class ProcessCollector(Collector):
     """Collector for Standard Exports such as cpu and memory."""
 
-    def __init__(self, namespace='', pid=lambda: 'self', proc='/proc', registry=REGISTRY):
+    def __init__(self,
+                 namespace: str = '',
+                 pid: Callable[[], Union[int, str]] = lambda: 'self',
+                 proc: str = '/proc',
+                 registry: CollectorRegistry = REGISTRY):
         self._namespace = namespace
         self._pid = pid
         self._proc = proc
@@ -37,7 +40,7 @@ class ProcessCollector(object):
         self._btime = 0
         try:
             self._btime = self._boot_time()
-        except IOError:
+        except OSError:
             pass
         if registry:
             registry.register(self)
@@ -48,7 +51,7 @@ class ProcessCollector(object):
                 if line.startswith(b'btime '):
                     return float(line.split()[1])
 
-    def collect(self):
+    def collect(self) -> Iterable[Metric]:
         if not self._btime:
             return []
 
@@ -73,7 +76,7 @@ class ProcessCollector(object):
                                       'Total user and system CPU time spent in seconds.',
                                       value=utime + stime)
             result.extend([vmem, rss, start_time, cpu])
-        except IOError:
+        except OSError:
             pass
 
         try:
@@ -88,7 +91,7 @@ class ProcessCollector(object):
                                          'Number of open file descriptors.',
                                          len(os.listdir(os.path.join(pid, 'fd'))))
             result.extend([open_fds, max_fds])
-        except (IOError, OSError):
+        except OSError:
             pass
 
         return result
